import './routes/index.ts';
import { app } from './app.ts';
import { useConfig } from '@kevisual/use-config';
import { User } from './models/user.ts';
import { createAuthRoute } from '@kevisual/auth';
const config = useConfig<{ tokenSecret: string }>();

createAuthRoute({
  app,
  secret: config.tokenSecret,
});

app
  .route({
    path: 'auth',
    key: 'admin',
    id: 'auth-admin',
    isDebug: true,
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    const tokenUser = ctx.state.tokenUser;
    if (!tokenUser) {
      ctx.throw(401, 'No User For authorized');
    }
    try {
      const user = await User.findOne({
        where: {
          id: tokenUser.id,
        },
      });
      if (!user) {
        ctx.throw(404, 'user not found');
      }
      user.setTokenUser(tokenUser);
      const orgs = await user.getOrgs();

      if (orgs.includes('admin')) {
        ctx.body = 'admin';
        ctx.nextQuery = ctx.query;
      } else {
        ctx.throw(403, 'forbidden');
      }
    } catch (e) {
      console.error('auth-admin error', e);
      ctx.throw(500, e.message);
    }
  })
  .addTo(app);

app
  .route({
    path: 'test',
    key: 'test',
  })
  .define(async (ctx) => {
    ctx.body = app.router.routes.map((item) => {
      return {
        path: item.path,
        key: item.key,
        description: item.description,
        validator: item.validator,
        // schema: item.schema,
      };
    });
  })
  .addTo(app);
